@@ -17,7 +17,7 @@ def main():
     print(cwd)
     print(__file__)
 
-    parser = argparse.ArgumentParser()
+    parser = argparse.ArgumentParser('recaud')
     parser.add_argument('--config', '-c')
     parser.add_argument('--output', '-o')
 
